@@ -10,7 +10,7 @@ class TrainingManager(object):
 
     @staticmethod
     def shell_training(cmd_str):
-        Logger.info(f"Process {os.getpid()} is running")
+        Logger.get_logger().(f"Process {os.getpid()} is running")
         os.system(cmd_str)
 
     def start_shell_training(self, cmd_strs):
